@@ -27,9 +27,7 @@ from ..decompiler import DecompileCtx, decompiler
 from ..gir import StringType, BoolType, IntType, FloatType, GirType, Enumeration
 from ..lsp_utils import Completion, CompletionItemKind, SemanticToken, SemanticTokenType
 from ..parse_tree import *
-from ..xml_emitter import XmlEmitter
 
 
-OBJECT_HOOKS = AnyOf()
 OBJECT_CONTENT_HOOKS = AnyOf()
 VALUE_HOOKS = AnyOf()
